# raxml

**DOI:** [10.5281/zenodo.7968243](https://doi.org/10.5281/zenodo.7968243)

## Available Versions
- **Version 8.2.12**
  - [Download](https://zenodo.org/record/7968244/files/raxml_8.2.12.img)
  - **MD5:** `d0cdbc2ba224a36e1de2b19dfa942c42`
  - **DOI:** [10.5281/zenodo.7968244](https://doi.org/10.5281/zenodo.7968244)
  - **Size:** 57.42 MB
  - **Binaries:** 0 available

## Binaries (6 total)

```raxmlHPC raxmlHPC-PTHREADS raxmlHPC-PTHREADS-SSE3 raxmlHPC-AVX2 raxmlHPC-PTHREADS-AVX2 raxmlHPC-SSE3```
